@@ -13,6 +13,7 @@ import logging
 import traceback
 import sys
 from logging import Logger as PythonLogger, DEBUG, StreamHandler
+from time import sleep
 from everysk.config import settings
 from everysk.core import log as log_module
 from everysk.core.unittests import TestCase, skipIf, mock
@@ -48,7 +49,7 @@ class LoggerJsonTestCase(TestCase):
                 '"logging.googleapis.com/spanId": "", '
                 '"logging.googleapis.com/trace_sampled": false, '
                 '"logging.googleapis.com/sourceLocation":'
-                ' {"file": "/var/app/src/everysk/core/_tests/log.py", "line": 39, "function": "test_info_as_json"}}\n'
+                ' {"file": "/var/app/src/everysk/core/_tests/log.py", "line": 40, "function": "test_info_as_json"}}\n'
             )
 
     def test_info_as_json_with_labels(self):
@@ -65,7 +66,7 @@ class LoggerJsonTestCase(TestCase):
                 '"logging.googleapis.com/spanId": "", '
                 '"logging.googleapis.com/trace_sampled": false, '
                 '"logging.googleapis.com/sourceLocation":'
-                ' {"file": "/var/app/src/everysk/core/_tests/log.py", "line": 56, "function": "test_info_as_json_with_labels"}}\n'
+                ' {"file": "/var/app/src/everysk/core/_tests/log.py", "line": 57, "function": "test_info_as_json_with_labels"}}\n'
             )
 
     def test_info_as_json_with_labels_as_bytes(self):
@@ -82,7 +83,7 @@ class LoggerJsonTestCase(TestCase):
                 '"logging.googleapis.com/spanId": "", '
                 '"logging.googleapis.com/trace_sampled": false, '
                 '"logging.googleapis.com/sourceLocation":'
-                ' {"file": "/var/app/src/everysk/core/_tests/log.py", "line": 73, "function": "test_info_as_json_with_labels_as_bytes"}}\n'
+                ' {"file": "/var/app/src/everysk/core/_tests/log.py", "line": 74, "function": "test_info_as_json_with_labels_as_bytes"}}\n'
             )
 
     def test_info_as_json_with_labels_with_bytes(self):
@@ -99,7 +100,7 @@ class LoggerJsonTestCase(TestCase):
                 '"logging.googleapis.com/spanId": "", '
                 '"logging.googleapis.com/trace_sampled": false, '
                 '"logging.googleapis.com/sourceLocation":'
-                ' {"file": "/var/app/src/everysk/core/_tests/log.py", "line": 90, "function": "test_info_as_json_with_labels_with_bytes"}}\n'
+                ' {"file": "/var/app/src/everysk/core/_tests/log.py", "line": 91, "function": "test_info_as_json_with_labels_with_bytes"}}\n'
             )
 
     @mock.patch.dict('os.environ', {'EVERYSK_GOOGLE_CLOUD_PROJECT': 'g-project'})
@@ -117,7 +118,7 @@ class LoggerJsonTestCase(TestCase):
                 '"logging.googleapis.com/spanId": "1c6c592f9e46e3fb", '
                 '"logging.googleapis.com/trace_sampled": true, '
                 '"logging.googleapis.com/sourceLocation":'
-                ' {"file": "/var/app/src/everysk/core/_tests/log.py", "line": 108, "function": "test_info_as_json_with_http_headers"}}\n'
+                ' {"file": "/var/app/src/everysk/core/_tests/log.py", "line": 109, "function": "test_info_as_json_with_http_headers"}}\n'
             )
 
     def test_error_as_json(self):
@@ -139,7 +140,7 @@ class LoggerJsonTestCase(TestCase):
                 '"logging.googleapis.com/spanId": "", '
                 '"logging.googleapis.com/trace_sampled": false, '
                 '"logging.googleapis.com/sourceLocation":'
-                ' {"file": "/var/app/src/everysk/core/_tests/log.py", "line": 130, "function": "test_error_as_json"}}\n'
+                ' {"file": "/var/app/src/everysk/core/_tests/log.py", "line": 131, "function": "test_error_as_json"}}\n'
             )
 
 
@@ -645,6 +646,34 @@ class LoggerSlackTestCase(TestCase):
         log_mock.log.assert_called_once_with(logging.ERROR, 'Slack message: Error -> Error message', extra={'labels': {}}, stacklevel=2)
         slack.assert_called_once_with(title='Error', message='Error message', color='danger', url='http://google.com')
 
+    def test_slack_time_check(self, slack: mock.MagicMock, log_mock: mock.MagicMock):
+        log = log_module.Logger(name='everysk-lib-test-slack-message')
+        log.slack(title='Error', message='Error message', color='danger', url='http://google.com')
+        log.slack(title='Error', message='Error message', color='danger', url='http://google.com')
+        slack.assert_called_once_with(title='Error', message='Error message', color='danger', url='http://google.com')
+        log_mock.log.assert_has_calls([
+            mock.call(40, 'Slack message: Error -> Error message', extra={'labels': {}}, stacklevel=2),
+            mock.call(40, 'Slack message: Error -> Error message', extra={'labels': {}}, stacklevel=2)
+        ])
+
+    def test_slack_time_check_3s(self, slack: mock.MagicMock, log_mock: mock.MagicMock):
+        log = log_module.Logger(name='everysk-lib-test-slack-message')
+        log.slack(title='Error', message='Error message', color='danger', url='http://google.com')
+        log.slack(title='Error', message='Error message', color='danger', url='http://google.com')
+        sleep(3)
+        log.slack(title='Error', message='Error message', color='danger', url='http://google.com')
+        slack.assert_has_calls([
+            mock.call(title='Error', message='Error message', color='danger', url='http://google.com'),
+            mock.call().send(),
+            mock.call(title='Error', message='Error message', color='danger', url='http://google.com'),
+            mock.call().send()
+        ])
+        log_mock.log.assert_has_calls([
+            mock.call(40, 'Slack message: Error -> Error message', extra={'labels': {}}, stacklevel=2),
+            mock.call(40, 'Slack message: Error -> Error message', extra={'labels': {}}, stacklevel=2),
+            mock.call(40, 'Slack message: Error -> Error message', extra={'labels': {}}, stacklevel=2)
+        ])
+
 
 class LoggerFormatterTestCase(TestCase):
 
