@@ -14,9 +14,11 @@ import traceback as python_traceback
 import sys
 from contextlib import AbstractContextManager
 from contextvars import ContextVar
+from datetime import datetime as DateTime
 from types import TracebackType
 from typing import Any
 from threading import Thread
+from zoneinfo import ZoneInfo
 from everysk.config import settings
 
 try:
@@ -350,11 +352,10 @@ class Logger:
 
     ## Private attributes
     _deprecated_hash: set[str] = set() # This needs to be initialized with an empty set because it will be a global list
-    _log: logging.Logger = None
     _default_stacklevel: int = 2
-    _http_functions = {
-        'flask': {'http_headers': _get_flask_headers, 'http_payload': _get_flask_payload},
-    }
+    _http_functions = {'flask': {'http_headers': _get_flask_headers, 'http_payload': _get_flask_payload}}
+    _log: logging.Logger = None
+    _slack_timer: DateTime = None
 
     ## Public attributes
     name: str = None
@@ -630,6 +631,18 @@ class Logger:
         """
         self._send_to_log(logging.INFO, msg, *args, extra=extra, stacklevel=stacklevel)
 
+    def _can_send_slack(self) -> bool:
+        """
+        Check if the slack message can be sent.
+        We keep a track of the last message sent to avoid sending too many messages in less than 3 seconds.
+        """
+        now = DateTime.now(ZoneInfo('UTC')) # pylint: disable=no-member
+        if self._slack_timer and (now - self._slack_timer).seconds < 2:
+            return False
+
+        self._slack_timer = now
+        return True
+
     def slack(self, title: str, message: str, color: str, url: str = None, extra: dict = None, stacklevel: int = None) -> None:
         """
         Send a message to a Slack channel using Slack WebHooks.
@@ -650,13 +663,15 @@ class Logger:
         if url is None:
             url = settings.SLACK_URL
 
-        # We send the message only if url is set and we are in PROD
+        # We send the message only if url is set and we are in PROD and not in unittest
         if url and settings.PROFILE == 'PROD' and 'unittest' not in sys.modules:
-            # The import must be here to avoid circular import inside http module
-            from everysk.core.slack import Slack # pylint: disable=import-outside-toplevel
-            client = Slack(title=title, message=message, color=color, url=url)
-            # This will send the message to Slack without block the request
-            Thread(target=client.send).start()
+            # We check if the last message was sent in less than 3 seconds to avoid sending too many messages
+            if self._can_send_slack():
+                # The import must be here to avoid circular import inside http module
+                from everysk.core.slack import Slack # pylint: disable=import-outside-toplevel
+                client = Slack(title=title, message=message, color=color, url=url)
+                # This will send the message to Slack without block the request
+                Thread(target=client.send).start()
 
         log_message = f'Slack message: {title} -> {message}'
         if color == 'danger':
