@@ -238,6 +238,24 @@ class QueryTestCase(TestCase):
         self.assertEqual(self.query.projection, properties)
         self.assertIs(result, self.query)
 
+    def test_set_projection_id_on_custom_index(self):
+        from everysk.sdk.entities.custom_index.base import CustomIndex # pylint: disable=import-outside-toplevel
+        properties = ['id']
+        query = Query(CustomIndex)
+        result = query.set_projection(properties)
+
+        self.assertEqual(query.projection, properties)
+        self.assertIs(result, query)
+
+    def test_set_projection_id_on_private_security(self):
+        from everysk.sdk.entities.private_security.base import PrivateSecurity # pylint: disable=import-outside-toplevel
+        properties = ['id']
+        query = Query(PrivateSecurity)
+        result = query.set_projection(properties)
+
+        self.assertEqual(query.projection, properties)
+        self.assertIs(result, query)
+
     def test_set_projection_mixed_projection(self):
         properties = ['name', '-date']
         with self.assertRaises(ValueError) as context:
