@@ -304,7 +304,7 @@ class Query(BaseDict, BaseSDK):
         if not (count == 0 or count == len(projection)):
             raise ValueError('Projection and Inverse Projection should not be set in the same query')
 
-        entity_properties: set = set(self._klass().keys()) # pylint: disable=protected-access
+        entity_properties: set = set(self._klass.__attributes__.keys()) # pylint: disable=protected-access
         projection_properties: set = set([property_name.replace('-', '') for property_name in projection])
         difference: set = projection_properties.difference(entity_properties)
 
